
API References
==============

.. automodule:: filefinder

.. rubric:: Content
.. autosummary::
   :nosignatures:

   finder.Finder

.. rubric:: Submodules
.. autosummary::
   :toctree: _api

   finder
   filters
   format
   group
   library
   matches
